# -*- coding: utf-8 -*-

from zope.schema import TextLine
from zope.schema.fieldproperty import FieldProperty
from zope.interface import implements
from zope.contenttype import guess_content_type
from zope.app.file import File
from zope.app.file.interfaces import IFile


def cleanupFileName(filename):
    return unicode(filename.split('\\')[-1].split('/')[-1])


class INamedFile(IFile):
    """Defines a file that is aware of its filename.
    """
    filename = TextLine(
        title = u"Name of file",
        required = True,
        default = u''
        )


class NamedFile(File):
    """A simple INamedFile implementation that can guess the content type
    from the value and the filename.
    """
    implements(INamedFile)
    filename = FieldProperty(INamedFile['filename'])
    
    def __init__(self, data='', contentType='', filename=None):
        self.data = data
        if filename is not None:
            self.filename = cleanupFileName(filename)
        if not contentType and filename:
            # If we handle large files, we don't want them read just
            # to guess the content type. We provide only the filename.
            self.contentType, enc = guess_content_type(name=filename)
        else:
            self.contentType = contentType



# -*- coding: utf-8 -*-

from zope import schema, interface


class IFileField(interface.Interface):
    """A field storing binary datas.
    """


class FileField(schema.Field):
    interface.implements(IFileField)

    def __init__(self, **kw):
        super(FileField, self).__init__(**kw)

    def _validate(self, value):
        super(FileField, self)._validate(value)



# -*- coding: utf-8 -*-

from dolmen.file.field import FileField, IFileField
from dolmen.file.file import NamedFile, INamedFile
from dolmen.file.access import FilePublisher, FileTraverser, DownloadTraverser
from dolmen.file.property import FileProperty



from os.path import join
from setuptools import setup, find_packages

version = '0.1'

setup(name='dolmen.file',
      version=version,
      description="A Zope3/Grok File Representation package.",
      long_description= "%s\n\n%s" % (
          open(join('src', 'dolmen','file', 'README.txt')).read(),
          open(join('docs', 'HISTORY.txt')).read(),
          ),
      classifiers=[
          "Framework :: Zope3",
          "Programming Language :: Python",
          "Topic :: Software Development :: Libraries :: Python Modules",
          ],
      keywords='Grok Zope3 file download',
      author='Souheil Chelfouh',
      author_email='trollfot@gmail.com',
      url='',
      license='GPL',
      packages=find_packages('src', exclude=['ez_setup']),
      package_dir={'': 'src'},
      namespace_packages=['dolmen'],
      include_package_data=True,
      zip_safe=False,
      install_requires=[
          'setuptools',
          'grokcore.view',
          'zope.schema',
          'zope.security',
          'zope.interface',
          'zope.component',
          'zope.publisher',
          'zope.traversing',
          'zope.contenttype',
          'zope.app.file',
          'dolmen.builtins',
      ],
      entry_points="""
      # -*- Entry points: -*-
      """,
      )



import os.path
import unittest
from zope.testing import doctest, module
from zope.app.testing import functional

ftesting_zcml = os.path.join(os.path.dirname(__file__), 'ftesting.zcml')
FunctionalLayer = functional.ZCMLLayer(
    ftesting_zcml, __name__, 'FunctionalLayer',allow_teardown=True)


def test_suite():
    """Testing suite.
    """
    readme = functional.FunctionalDocFileSuite('README.txt',
        optionflags=(doctest.ELLIPSIS + doctest.NORMALIZE_WHITESPACE),
        )

    readme.layer = FunctionalLayer
    suite = unittest.TestSuite()
    suite.addTest(readme)
    return suite

if __name__ == '__main__':
    unittest.main(defaultTest='test_suite')
